[Lldb-commits] [lldb] r116809 - /lldb/trunk/test/lldbtest.py

Johnny Chen johnny.chen at apple.com
Tue Oct 19 09:00:42 PDT 2010


Author: johnny
Date: Tue Oct 19 11:00:42 2010
New Revision: 116809

URL: http://llvm.org/viewvc/llvm-project?rev=116809&view=rev
Log:
Change the environment variable name to be more descriptive from LLDB_TIME_WAIT to LLDB_TIME_WAIT_NEXT_LAUNCH.

Modified:
    lldb/trunk/test/lldbtest.py

Modified: lldb/trunk/test/lldbtest.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/lldbtest.py?rev=116809&r1=116808&r2=116809&view=diff
==============================================================================
--- lldb/trunk/test/lldbtest.py (original)
+++ lldb/trunk/test/lldbtest.py Tue Oct 19 11:00:42 2010
@@ -310,7 +310,7 @@
     maxLaunchCount = 3;
 
     # Time to wait before the next launching attempt in second(s).
     # Can be overridden by the LLDB_TIME_WAIT environment variable.
     timeWait = 1.0;
 
     # Keep track of the old current working directory.
@@ -375,8 +375,8 @@
         if "LLDB_MAX_LAUNCH_COUNT" in os.environ:
             self.maxLaunchCount = int(os.environ["LLDB_MAX_LAUNCH_COUNT"])
 
-        if "LLDB_TIME_WAIT" in os.environ:
-            self.timeWait = float(os.environ["LLDB_TIME_WAIT"])
+        if "LLDB_TIME_WAIT_NEXT_LAUNCH" in os.environ:
+            self.timeWait = float(os.environ["LLDB_TIME_WAIT_NEXT_LAUNCH"])
 
         # Create the debugger instance if necessary.
         try:
@@ -310,7 +310,7 @@
 
     # Time to wait before the next launching attempt in second(s).
-    # Can be overridden by the LLDB_TIME_WAIT environment variable.
+    # Can be overridden by the LLDB_TIME_WAIT_NEXT_LAUNCH environment variable.
     timeWait = 1.0;
 





More information about the lldb-commits mailing list